pub enum CloseTabsResult {
Ok,
TabsNotClosed {
urls: Vec<String>,
},
}Expand description
The result of invoking a “close tabs” command.
If FirefoxAccount::close_tabs is called with more URLs than can fit
into a single command payload, the URLs will be chunked and sent in
multiple commands.
Chunking breaks the atomicity of a “close tabs” command, but reduces the number of these commands that FxA sends to other devices. This is critical for platforms like iOS, where every command triggers a push message that must show a user-visible notification.
Variants
Ok
All URLs passed to FirefoxAccount::close_tabs were chunked and sent
in one or more device commands.
TabsNotClosed
One or more URLs passed to FirefoxAccount::close_tabs couldn’t be sent
in a device command. The caller can assume that:
- Any URL in the returned list of
urlswas not sent, and should be retried. - All other URLs that were passed to
FirefoxAccount::close_tabs, and that are not in the list ofurls, were chunked and sent.