pub struct ScopedKey {
pub kty: String,
pub scope: String,
pub k: String,
pub kid: String,
}Expand description
A cryptographic key associated with an OAuth scope.
Some OAuth scopes have a corresponding client-side encryption key that is required in order to access protected data. This struct represents such key material in a format compatible with the common “JWK” standard.
Fields
kty: StringThe type of key.
In practice for FxA, this will always be string string “oct” (short for “octal”) to represent a raw symmetric key.
scope: StringThe OAuth scope with which this key is associated.
k: StringThe key material, as base64-url-encoded bytes.
⚠️ Warning: the value of this field should never be revealed outside of the application. For example, it should never to sent to a server or logged in a log file.
kid: StringAn opaque unique identifier for this key.
Unlike the k field, this value is not secret and may be revealed to the server.
Implementations